==> gravestones-1.2.0%2B1.21.8%2BA-sources.jar: net/pneumono/gravestones/multiversion/VersionUtil.java <==
package net.pneumono.gravestones.multiversion;

import com.mojang.authlib.GameProfile;
import com.mojang.serialization.Codec;
import com.mojang.serialization.DynamicOps;
import java.util.Optional;
import java.util.UUID;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2499;
import net.minecraft.class_2509;
import net.minecraft.class_2520;
import net.minecraft.class_4208;
import net.minecraft.class_5321;
import net.minecraft.class_9296;

public class VersionUtil {
    public static UUID getId(GameProfile profile) {
        //? if >=1.21.9 {
        /*return profile.id();
        *///?} else {
        return profile.getId();
        //?}
    }

    public static String getName(GameProfile profile) {
        //? if >=1.21.9 {
        /*return profile.name();
        *///?} else {
        return profile.getName();
         //?}
    }

    //? if >=1.20.6 {
    public static GameProfile getGameProfile(class_9296 profile) {
        //? if >=1.21.9 {
        /*return profile.getGameProfile();
        *///?} else {
        return profile.comp_2413();
        //?}
    }
    //?}

    public static class_4208 createGlobalPos(class_5321<class_1937> dimension, class_2338 pos) {
        //? if >=1.20.6 {
        return new class_4208(dimension, pos);
        //?} else {
        /*return GlobalPos.create(dimension, pos);
        *///?}
    }

    public static class_2338 getPos(class_4208 pos) {
        //? if >=1.20.6 {
        return pos.comp_2208();
        //?} else {
        /*return pos.getPos();
        *///?}
    }

    public static class_5321<class_1937> getDimension(class_4208 pos) {
        //? if >=1.20.6 {
        return pos.comp_2207();
        //?} else {
        /*return pos.getDimension();
        *///?}
    }

    public static <T> void put(class_2487 nbt, String key, Codec<T> codec, T object) {
        put(class_2509.field_11560, nbt, key, codec, object);
    }

    @SuppressWarnings("unused")
    public static <T> void put(DynamicOps<class_2520> ops, class_2487 nbt, String key, Codec<T> codec, T object) {
        //? if >=1.21.5 {
        nbt.method_67494(key, codec, object);
        //?} else {
        /*nbt.put(key, codec.encodeStart(ops, object).result().orElseThrow());
        *///?}
    }

    public static <T> Optional<T> get(class_2487 nbt, String key, Codec<T> codec) {
        return get(class_2509.field_11560, nbt, key, codec);
    }

    @SuppressWarnings("unused")
    public static <T> Optional<T> get(DynamicOps<class_2520> ops, class_2487 nbt, String key, Codec<T> codec) {
        //? if >=1.21.5 {
        return nbt.method_67491(key, codec);
        //?} else {
        /*return codec.decode(ops, nbt.get(key)).result().map(Pair::getFirst);
        *///?}
    }

    public static class_2487 getCompoundOrEmpty(class_2487 nbt, String key) {
        //? if >=1.21.5 {
        return nbt.method_68568(key);
        //?} else {
        /*return nbt.getCompound(key);
        *///?}
    }

    public static class_2499 getCompoundListOrEmpty(class_2487 nbt, String key) {
        //? if >=1.21.5 {
        return nbt.method_68569(key);
        //?} else {
        /*return nbt.getList(key, NbtElement.COMPOUND_TYPE);
        *///?}
    }
}

==> gravestones-1.2.1%2B1.21.9%2BA-sources.jar: net/pneumono/gravestones/multiversion/VersionUtil.java <==
package net.pneumono.gravestones.multiversion;

import com.mojang.authlib.GameProfile;
import com.mojang.serialization.Codec;
import com.mojang.serialization.DynamicOps;
import java.util.Optional;
import java.util.UUID;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2499;
import net.minecraft.class_2509;
import net.minecraft.class_2520;
import net.minecraft.class_4208;
import net.minecraft.class_5321;
import net.minecraft.class_9296;

public class VersionUtil {
    public static UUID getId(GameProfile profile) {
        //? if >=1.21.9 {
        return profile.id();
        //?} else {
        /*return profile.getId();
        *///?}
    }

    public static String getName(GameProfile profile) {
        //? if >=1.21.9 {
        return profile.name();
        //?} else {
        /*return profile.getName();
         *///?}
    }

    //? if >=1.20.6 {
    public static GameProfile getGameProfile(class_9296 profile) {
        //? if >=1.21.9 {
        return profile.method_73313();
        //?} else {
        /*return profile.gameProfile();
        *///?}
    }
    //?}

    public static class_4208 createGlobalPos(class_5321<class_1937> dimension, class_2338 pos) {
        //? if >=1.20.6 {
        return new class_4208(dimension, pos);
        //?} else {
        /*return GlobalPos.create(dimension, pos);
        *///?}
    }

    public static class_2338 getPos(class_4208 pos) {
        //? if >=1.20.6 {
        return pos.comp_2208();
        //?} else {
        /*return pos.getPos();
        *///?}
    }

    public static class_5321<class_1937> getDimension(class_4208 pos) {
        //? if >=1.20.6 {
        return pos.comp_2207();
        //?} else {
        /*return pos.getDimension();
        *///?}
    }

    public static <T> void put(class_2487 nbt, String key, Codec<T> codec, T object) {
        put(class_2509.field_11560, nbt, key, codec, object);
    }

    @SuppressWarnings("unused")
    public static <T> void put(DynamicOps<class_2520> ops, class_2487 nbt, String key, Codec<T> codec, T object) {
        //? if >=1.21.5 {
        nbt.method_67494(key, codec, object);
        //?} else {
        /*nbt.put(key, codec.encodeStart(ops, object).result().orElseThrow());
        *///?}
    }

    public static <T> Optional<T> get(class_2487 nbt, String key, Codec<T> codec) {
        return get(class_2509.field_11560, nbt, key, codec);
    }

    @SuppressWarnings("unused")
    public static <T> Optional<T> get(DynamicOps<class_2520> ops, class_2487 nbt, String key, Codec<T> codec) {
        //? if >=1.21.5 {
        return nbt.method_67491(key, codec);
        //?} else {
        /*return codec.decode(ops, nbt.get(key)).result().map(Pair::getFirst);
        *///?}
    }

    public static class_2487 getCompoundOrEmpty(class_2487 nbt, String key) {
        //? if >=1.21.5 {
        return nbt.method_68568(key);
        //?} else {
        /*return nbt.getCompound(key);
        *///?}
    }

    public static class_2499 getCompoundListOrEmpty(class_2487 nbt, String key) {
        //? if >=1.21.5 {
        return nbt.method_68569(key);
        //?} else {
        /*return nbt.getList(key, NbtElement.COMPOUND_TYPE);
        *///?}
    }
}
